@@ -7,7 +7,7 @@ while (<>)
 
 do 
 {
- print "($1,$2)\n" if (/\s*\d+\s+(\d+)\s+(\d+)/) ;
+ print "($1,$2)\n" if (/\s*\d+\s+(-?\d+)\s+(-?\d+)/) ;
  exit() if (/EOF/);
 } while (<>);
 
