@@ -4,6 +4,8 @@ module Main where
 import Point
 import TourEval
 import List
+import Control.Exception
+import System.CPUTime
 
 -- program execution starts by calling function main, defined next
 
@@ -17,9 +19,17 @@ import List
 -}
 
 main = readIntPts [] >>= \pts -> let tour = toureval pts
-                                 in putStr (showPoints tour)
-			{-	    if (sort tour) == (sort pts)
-                                    then putStr (showPoints tour)
-                                    else error "tour eval" 
-			-}
+                                 in putStr (showPoints (tourOK pts tour))
+{-
+main = do
+	pts <- readIntPts [] 
+        t0 <- getCPUTime
+	tour <- return (toureval pts)
+        t1 <- getCPUTime
+        putStr (showPoints (tourOK pts tour))
+        putStrLn ("Run Time: "++(show (time (t1-t0)))++"s")
 
+time t = ((fromInteger t)/(10^12))
+-}
+
+tourOK pts tour = assert (sort pts == sort tour) tour
